summaryrefslogtreecommitdiffstats
path: root/kalzium/src/somwidget_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/somwidget_impl.h')
-rw-r--r--kalzium/src/somwidget_impl.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kalzium/src/somwidget_impl.h b/kalzium/src/somwidget_impl.h
index ab616f54..5d32dbdc 100644
--- a/kalzium/src/somwidget_impl.h
+++ b/kalzium/src/somwidget_impl.h
@@ -29,13 +29,14 @@ class Element;
class SOMWidgetIMPL : public SOMWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent The parent of this widget
* @param name The name of this widget
*/
- SOMWidgetIMPL( TQWidget *parent = 0, const char* name = 0 );
+ SOMWidgetIMPL( TQWidget *tqparent = 0, const char* name = 0 );
public slots:
/**
@@ -29,13 +29,14 @@ class Element;
public:
/**
- * @param parent The parent of this widget
+ * @param tqparent The tqparent of this widget
* @param name The name of this widget
*/